AZURE_TRANSCRIBE_LANGUAGES = {
    "Afrikaans (South Africa)": "af-ZA",
    "Amharic (Ethiopia)": "am-ET",
    "Arabic (Algeria)": "ar-DZ",
    "Arabic (Bahrain), modern standard": "ar-BH",
    "Arabic (Egypt)": "ar-EG",
    "Arabic (Iraq)": "ar-IQ",
    "Arabic (Israel)": "ar-IL",
    "Arabic (Jordan)": "ar-JO",
    "Arabic (Kuwait)": "ar-KW",
    "Arabic (Lebanon)": "ar-LB",
    "Arabic (Libya)": "ar-LY",
    "Arabic (Morocco)": "ar-MA",
    "Arabic (Oman)": "ar-OM",
    "Arabic (Palestinian Authority)": "ar-PS",
    "Arabic (Qatar)": "ar-QA",
    "Arabic (Saudi Arabia)": "ar-SA",
    "Arabic (Syria)": "ar-SY",
    "Arabic (Tunisia)": "ar-TN",
    "Arabic (United Arab Emirates)": "ar-AE",
    "Arabic (Yemen)": "ar-YE",
    "Bengali (India)": "bn-IN",
    "Bulgarian (Bulgaria)": "bg-BG",
    "Burmese (Myanmar)": "my-MM",
    "Catalan (Spain)": "ca-ES",
    "Chinese (Cantonese, Traditional)": "zh-HK",
    "Chinese (Mandarin, Simplified)": "zh-CN",
    "Chinese (Taiwanese Mandarin)": "zh-TW",
    "Croatian (Croatia)": "hr-HR",
    "Czech (Czech)": "cs-CZ",
    "Danish (Denmark)": "da-DK",
    "Dutch (Belgium)": "nl-BE",
    "Dutch (Netherlands)": "nl-NL",
    "English (Australia)": "en-AU",
    "English (Canada)": "en-CA",
    "English (Ghana)": "en-GH",
    "English (Hong Kong)": "en-HK",
    "English (India)": "en-IN",
    "English (Ireland)": "en-IE",
    "English (Kenya)": "en-KE",
    "English (New Zealand)": "en-NZ",
    "English (Nigeria)": "en-NG",
    "English (Philippines)": "en-PH",
    "English (Singapore)": "en-SG",
    "English (South Africa)": "en-ZA",
    "English (Tanzania)": "en-TZ",
    "English (United Kingdom)": "en-GB",
    "English (United States)": "en-US",
    "Estonian (Estonia)": "et-EE",
    "Filipino (Philippines)": "fil-PH",
    "Finnish (Finland)": "fi-FI",
    "French (Belgium)": "fr-BE",
    "French (Canada)": "fr-CA",
    "French (France)": "fr-FR",
    "French (Switzerland)": "fr-CH",
    "German (Austria)": "de-AT",
    "German (Germany)": "de-DE",
    "German (Switzerland)": "de-CH",
    "Greek (Greece)": "el-GR",
    "Gujarati (India)": "gu-IN",
    "Hebrew (Israel)": "he-IL",
    "Hindi (India)": "hi-IN",
    "Hungarian (Hungary)": "hu-HU",
    "Icelandic (Iceland)": "is-IS",
    "Indonesian (Indonesia)": "id-ID",
    "Irish (Ireland)": "ga-IE",
    "Italian (Italy)": "it-IT",
    "Japanese (Japan)": "ja-JP",
    "Javanese (Indonesia)": "jv-ID",
    "Kannada (India)": "kn-IN",
    "Khmer (Cambodia)": "km-KH",
    "Korean (Korea)": "ko-KR",
    "Lao (Laos)": "lo-LA",
    "Latvian (Latvia)": "lv-LV",
    "Lithuanian (Lithuania)": "lt-LT",
    "Macedonian (North Macedonia)": "mk-MK",
    "Malay (Malaysia)": "ms-MY",
    "Maltese (Malta)": "mt-MT",
    "Marathi (India)": "mr-IN",
    "Norwegian (Bokmål, Norway)": "no-NO",
    "Persian (Iran)": "fa-IR",
    "Polish (Poland)": "pl-PL",
    "Portuguese (Brazil)": "pt-BR",
    "Portuguese (Portugal)": "pt-PT",
    "Romanian (Romania)": "ro-RO",
    "Russian (Russia)": "ru-RU",
    "Serbian (Serbia)": "sr-RS",
    "Sinhala (Sri Lanka)": "si-LK",
    "Slovak (Slovakia)": "sk-SK",
    "Slovenian (Slovenia)": "sl-SI",
    "Spanish (Argentina)": "es-AR",
    "Spanish (Bolivia)": "es-BO",
    "Spanish (Chile)": "es-CL",
    "Spanish (Colombia)": "es-CO",
    "Spanish (Costa Rica)": "es-CR",
    "Spanish (Cuba)": "es-CU",
    "Spanish (Dominican Republic)": "es-DO",
    "Spanish (Ecuador)": "es-EC",
    "Spanish (El Salvador)": "es-SV",
    "Spanish (Equatorial Guinea)": "es-GQ",
    "Spanish (Guatemala)": "es-GT",
    "Spanish (Honduras)": "es-HN",
    "Spanish (Mexico)": "es-MX",
    "Spanish (Nicaragua)": "es-NI",
    "Spanish (Panama)": "es-PA",
    "Spanish (Paraguay)": "es-PY",
    "Spanish (Peru)": "es-PE",
    "Spanish (Puerto Rico)": "es-PR",
    "Spanish (Spain)": "es-ES",
    "Spanish (Uruguay)": "es-UY",
    "Spanish (USA)": "es-US",
    "Spanish (Venezuela)": "es-VE",
    "Swahili (Kenya)": "sw-KE",
    "Swahili (Tanzania)": "sw-TZ",
    "Swedish (Sweden)": "sv-SE",
    "Tamil (India)": "ta-IN",
    "Telugu (India)": "te-IN",
    "Thai (Thailand)": "th-TH",
    "Turkish (Turkey)": "tr-TR",
    "Ukrainian (Ukraine)": "uk-UA",
    "Uzbek (Uzbekistan)": "uz-UZ",
    "Vietnamese (Vietnam)": "vi-VN",
    "Zulu (South Africa)": "zu-ZA",
}

AZURE_TRANSCRIBE_LANGUAGES_CODES = [
    "af-ZA",
    "am-ET",
    "ar-DZ",
    "ar-BH",
    "ar-EG",
    "ar-IQ",
    "ar-IL",
    "ar-JO",
    "ar-KW",
    "ar-LB",
    "ar-LY",
    "ar-MA",
    "ar-OM",
    "ar-PS",
    "ar-QA",
    "ar-SA",
    "ar-SY",
    "ar-TN",
    "ar-AE",
    "ar-YE",
    "bn-IN",
    "bg-BG",
    "my-MM",
    "ca-ES",
    "zh-HK",
    "zh-CN",
    "zh-TW",
    "hr-HR",
    "cs-CZ",
    "da-DK",
    "nl-BE",
    "nl-NL",
    "en-AU",
    "en-CA",
    "en-GH",
    "en-HK",
    "en-IN",
    "en-IE",
    "en-KE",
    "en-NZ",
    "en-NG",
    "en-PH",
    "en-SG",
    "en-ZA",
    "en-TZ",
    "en-GB",
    "en-US",
    "et-EE",
    "fil-PH",
    "fi-FI",
    "fr-BE",
    "fr-CA",
    "fr-FR",
    "fr-CH",
    "de-AT",
    "de-DE",
    "de-CH",
    "el-GR",
    "gu-IN",
    "he-IL",
    "hi-IN",
    "hu-HU",
    "is-IS",
    "id-ID",
    "ga-IE",
    "it-IT",
    "ja-JP",
    "jv-ID",
    "kn-IN",
    "km-KH",
    "ko-KR",
    "lo-LA",
    "lv-LV",
    "lt-LT",
    "mk-MK",
    "ms-MY",
    "mt-MT",
    "mr-IN",
    "no-NO",
    "fa-IR",
    "pl-PL",
    "pt-BR",
    "pt-PT",
    "ro-RO",
    "ru-RU",
    "sr-RS",
    "si-LK",
    "sk-SK",
    "sl-SI",
    "es-AR",
    "es-BO",
    "es-CL",
    "es-CO",
    "es-CR",
    "es-CU",
    "es-DO",
    "es-EC",
    "es-SV",
    "es-GQ",
    "es-GT",
    "es-HN",
    "es-MX",
    "es-NI",
    "es-PA",
    "es-PY",
    "es-PE",
    "es-PR",
    "es-ES",
    "es-UY",
    "es-US",
    "es-VE",
    "sw-KE",
    "sw-TZ",
    "sv-SE",
    "ta-IN",
    "te-IN",
    "th-TH",
    "tr-TR",
    "uk-UA",
    "uz-UZ",
    "vi-VN",
    "zu-ZA",
]
